package com.gic.haoban.manage.web.controller.hm;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.BasePageInfo;
import com.gic.api.base.commons.Page;
import com.gic.clerk.api.dto.ClerkStoreListDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.haoban.base.api.common.pojo.dto.WebLoginDTO;
import com.gic.haoban.common.utils.AuthWebRequestUtil;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.web.vo.hm.ClerkStoreListVO;

@RestController
public class HmStoreController {

    private static final Logger logger = LoggerFactory.getLogger(HmStoreController.class);

    @Autowired
    private ClerkService clerkService;
    @Autowired
    private StaffApiService staffApiService;

    @RequestMapping("store-clerk-list")
    @ResponseBody
    public RestResponse<Object> listStoreClerk(HttpServletRequest request, BasePageInfo basePageInfo) {
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        // 分组id
        String storeGroupId = request.getParameter("storeGroupId");
        // 门店参数
        String storeSearchParams = request.getParameter("storeSearchParams");
        // 导购参数
        String clerkSearchParams = request.getParameter("clerkSearchParams");
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("enterpriseId", loginUser.getEnterpriseId());
        // 2线上
        params.put("status", 2);
        params.put("storeGroupId", storeGroupId);
        // 是否显示子分组(1显示,其余不显示)
        params.put("showChildren", 1);
        // 只获取导购和店长
        params.put("clerkTypeList", Arrays.asList(1, 0));
        if (StringUtils.isNotBlank(storeSearchParams)) {
            params.put("storeSearchParams", "%" + storeSearchParams + "%");
        }
        if (StringUtils.isNotBlank(clerkSearchParams)) {
            params.put("clerkSearchParams", "%" + clerkSearchParams + "%");
        }
        // 如果有权限控制,进行管辖门店过0滤
        List<String> authStoreIdList = this.staffApiService.getHaoBanStoreIdsRolesByClerkId(loginUser.getClerkId(),
                loginUser.getWxEnterpriseId());
        if (CollectionUtils.isEmpty(authStoreIdList)) {
            return RestResponse.failure("-1", "无授权门店");
        }
        if (!(authStoreIdList.size() == 1 && authStoreIdList.contains("-1"))) {
            params.put("storeIdList", authStoreIdList);
        }
        Page<ClerkStoreListDTO> page = new Page<>();
        page.setPageSize(basePageInfo.getPageSize());
        page.setCurrentPage(basePageInfo.getPageNum());
        page.setParams(params);
        logger.info("params:{}", JSON.toJSONString(params));
        page = this.clerkService.listStoreClerkByPage(page);
        Page<ClerkStoreListVO> retPage = new Page<>();
        retPage.setPageSize(basePageInfo.getPageSize());
        retPage.setCurrentPage(basePageInfo.getPageNum());
        retPage.setParams(params);
        retPage.setTotalCount(page.getTotalCount());
        retPage.setTotalPage(page.getTotalPage());
        List<ClerkStoreListVO> result = EntityUtil.changeEntityListByJSON(ClerkStoreListVO.class, page.getResult()) ;
        // 好办状态
        retPage.setResult(result);
        return RestResponse.successResult(retPage);
    }
}
